# Ergate
Workflows made easy, your way.

> [!CAUTION]
> Ergate is still in its early stages of development and therefore breaking changes are possible between every version.

## Documentation
You can find the documentation for Ergate at [ergate.prryplatypus.dev](https://ergate.prryplatypus.dev).

## Acknowledgements
- [Ziply Fiber](https://ziplyfiber.com): For giving me the initial idea to create this project and allowing me to turn it into a personal, open-source project.
- [FastAPI](https://github.com/tiangolo/fastapi): For inspiring me on the implementation of a bunch of the features supported by Ergate (such as the use of `Depends` for argument injection).
- [Sanic](https://github.com/sanic-org/sanic): For getting me originally into the open-source world and for their use of unique names in blueprints (similar to workflows in Ergate).
